/*!
 * @name Attributes Plugin
 * @package es6tween-plugin-attr
 * @version v0.1-beta
 * @license MIT-License
 * @requires: es6-tween core files for running this plugin
 */

(function (factory) {
    "use strict";
    if (typeof define === "function" && define.amd) {
        define(['es6-tween', 'tweenizr'], function (es6Tween, Tweenizr) {
            return factory(es6Tween || Tweenizr);
        });
    } else if (typeof module !== "undefined" && module.exports && (require('es6-tween') || require('tweenizr'))) {
        module.exports = factory(require('es6-tween') || require('tweenizr'));
    } else if (typeof exports !== "undefined" && (exports.TWEEN || exports.Tweenizr)) {
        factory(exports.TWEEN || exports.Tweenizr);
    } else if (typeof window !== "undefined" && (window.TWEEN || window.Tweenizr)) {
        factory(window.TWEEN || window.Tweenizr);
    }
}
    (function (TWEEN) {
        "use strict";

        var Plugins = TWEEN.Plugins;
        var InterTween = TWEEN.Interpolator;

        var transform3dMap = {
            rotate: true,
            skew: true,
            scale: true,
            scaleX: true,
            scaleY: true,
            scaleZ: true,
            scale3d: true,
            translate: true,
            skewX: true,
            skewY: true,
            translate3d: true,
            z: true,
            rotate: true,
            rotateX: true,
            rotateY: true,
            rotateZ: true,
            scrollTop: true,
            scrollLeft: true
        };

        var attr = Plugins.attr = function (Tween, start, end) {
            this.node = Tween.node;
            this.vl = InterTween(start, end);
        }

        var p = attr.prototype;
        p.update = function (value) {
            var node = this.node;
            var vals = this.vl(value);

            for (var p in vals) {
                if (Plugins[p] || transform3dMap[p])
                    continue;
                node.setAttribute(p, vals[p]);
            }

        };
    }));
